# OpenBB Seeking Alpha Provider

This extension integrates the [Seeking Alpha](https://seekingalpha.com) data provider into the OpenBB Platform.

## Installation

To install the extension:

```bash
pip install openbb-seeking-alpha
```

Documentation available [here](https://docs.openbb.co/platform/developer_guide/contributing).
